@@ -116,6 +116,7 @@ static const char *tests[] = {
                               "kernel_reg",
                               "label_reg",
                               "lineremoval_reg",
+                              "locminmax_reg",
                               "logicops_reg",
                               "maze_reg",
                               "mtiff_reg",
@@ -152,12 +153,14 @@ static const char *tests[] = {
                               "shear1_reg",
                               "shear2_reg",
                               "skew_reg",
+                              "speckle_reg",
                               "splitcomp_reg",
                               "subpixel_reg",
                               "texturefill_reg",
                               "threshnorm_reg",
                               "translate_reg",
                               "warper_reg",
+                              "watershed_reg",
 #if HAVE_LIBWEBP
                               "webpio_reg",
 #endif  /* HAVE_LIBWEBP */
@@ -183,6 +186,7 @@ static char  mainName[] = "alltests_reg";
         return ERROR_INT(" Syntax alltests_reg [generate | compare | display]",
                          mainName, 1);
 
+    setLeptDebugOK(1);  /* required for testing */
     l_getCurrentTime(&start, NULL);
     ntests = sizeof(tests) / sizeof(char *);
     fprintf(stderr, "Running alltests_reg:\n"
