@@ -48,27 +48,30 @@ static char  mainName[] = "barcodetest";
 
     if (argc != 2)
         return ERROR_INT(" Syntax:  barcodetest filein", mainName, 1);
-
     filein = argv[1];
+
+    setLeptDebugOK(1);
+    lept_mkdir("lept/barc");
+
     if ((pixs = pixRead(filein)) == NULL)
         return ERROR_INT("pixs not made", mainName, 1);
 
     sad1 = pixProcessBarcodes(pixs, L_BF_ANY, L_USE_WIDTHS, &saw1, 0);
-    sarrayWrite("/tmp/junksaw1", saw1);
-    sarrayWrite("/tmp/junksad1", sad1);
+    sarrayWrite("/tmp/lept/barc/saw1", saw1);
+    sarrayWrite("/tmp/lept/barc/sad1", sad1);
     sarrayDestroy(&saw1);
     sarrayDestroy(&sad1);
 
     pixRotate180(pixs, pixs);
     sad2 = pixProcessBarcodes(pixs, L_BF_ANY, L_USE_WIDTHS, &saw2, 0);
-    sarrayWrite("/tmp/junksaw2", saw2);
-    sarrayWrite("/tmp/junksad2", sad2);
+    sarrayWrite("/tmp/lept/barc/saw2", saw2);
+    sarrayWrite("/tmp/lept/barc/sad2", sad2);
     sarrayDestroy(&saw2);
     sarrayDestroy(&sad2);
 
 /*    sad3 = pixProcessBarcodes(pixs, L_BF_ANY, L_USE_WINDOW, &saw3, 1);
-    sarrayWrite("/tmp/junksaw3", saw3);
-    sarrayWrite("/tmp/junksad3", sad3);
+    sarrayWrite("/tmp/lept/barc/saw3", saw3);
+    sarrayWrite("/tmp/lept/barc/sad3", sad3);
     sarrayDestroy(&saw3);
     sarrayDestroy(&sad3); */
 
