@@ -45,12 +45,12 @@ l_float32    diffarea, diffxor, scalefact;
 BOX         *box;
 BOXA        *boxa1, *boxa2, *boxa3;
 BOXAA       *baa1, *baa2, *baa3;
-PIX         *pix1, *pixdb;
+PIX         *pix1, *pix2, *pix3, *pixdb;
 PIXA        *pixa1, *pixa2;
-static char  mainName[] = "boxa1_reg";
+L_REGPARAMS  *rp;
 
-    if (argc != 1)
-        return ERROR_INT(" Syntax: boxa1_reg", mainName, 1);
+    if (regTestSetup(argc, argv, &rp))
+        return 1;
 
     lept_mkdir("lept/boxa");
 
@@ -69,30 +69,35 @@ static char  mainName[] = "boxa1_reg";
     box = boxCreate(117, 206, 26, 74);
     boxaAddBox(boxa1, box, L_INSERT);
     pix1 = DisplayBoxa(boxa1);
-    pixDisplay(pix1, 100, 100);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 0 */
+    pixDisplayWithTitle(pix1, 0, 0, NULL, rp->display);
     pixDestroy(&pix1);
 
     boxaCompareRegions(boxa1, boxa1, 100, &same, &diffarea, &diffxor, NULL);
-    fprintf(stderr, "same = %d, diffarea = %5.3f, diffxor = %5.3f\n",
-            same, diffarea, diffxor);
+    regTestCompareValues(rp, 1, same, 0.0);  /* 1 */
+    regTestCompareValues(rp, 0.0, diffarea, 0.0);  /* 2 */
+    regTestCompareValues(rp, 0.0, diffxor, 0.0);  /* 3 */
 
     boxa2 = boxaTransform(boxa1, -13, -13, 1.0, 1.0);
     boxaCompareRegions(boxa1, boxa2, 10, &same, &diffarea, &diffxor, NULL);
-    fprintf(stderr, "same = %d, diffarea = %5.3f, diffxor = %5.3f\n",
-            same, diffarea, diffxor);
+    regTestCompareValues(rp, 1, same, 0.0);  /* 4 */
+    regTestCompareValues(rp, 0.0, diffarea, 0.0);  /* 5 */
+    regTestCompareValues(rp, 0.0, diffxor, 0.0);  /* 6 */
     boxaDestroy(&boxa2);
 
     boxa2 = boxaReconcileEvenOddHeight(boxa1, L_ADJUST_TOP_AND_BOT, 6,
                                        L_ADJUST_CHOOSE_MIN, 1.0, 0);
     pix1 = DisplayBoxa(boxa2);
-    pixDisplay(pix1, 100, 500);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 7 */
+    pixDisplayWithTitle(pix1, 200, 0, NULL, rp->display);
     pixDestroy(&pix1);
 
     boxaCompareRegions(boxa1, boxa2, 10, &same, &diffarea, &diffxor, &pixdb);
-    fprintf(stderr, "same = %d, diffarea = %5.3f, diffxor = %5.3f\n",
-            same, diffarea, diffxor);
-    pixDisplay(pixdb, 700, 100);
-
+    regTestCompareValues(rp, 1, same, 0.0);  /* 8 */
+    regTestCompareValues(rp, 0.053, diffarea, 0.002);  /* 9 */
+    regTestCompareValues(rp, 0.240, diffxor, 0.002);  /* 10 */
+    regTestWritePixAndCheck(rp, pixdb, IFF_PNG);  /* 11 */
+    pixDisplayWithTitle(pixdb, 400, 0, NULL, rp->display);
     pixDestroy(&pixdb);
     boxaDestroy(&boxa1);
     boxaDestroy(&boxa2);
@@ -106,8 +111,8 @@ static char  mainName[] = "boxa1_reg";
     scalefact = (l_float32)width / (l_float32)w;
     boxa3 = boxaTransform(boxa2, 0, 0, scalefact, scalefact);
     pix1 = boxaDisplayTiled(boxa3, NULL, 1500, 2, 1.0, 0, 3, 2);
-    pixDisplay(pix1, 0, 100);
-    pixWrite("/tmp/lept/boxa/pix1.png", pix1, IFF_PNG);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 12 */
+    pixDisplayWithTitle(pix1, 600, 0, NULL, rp->display);
     pixDestroy(&pix1);
     boxaDestroy(&boxa1);
     boxaDestroy(&boxa2);
@@ -122,11 +127,31 @@ static char  mainName[] = "boxa1_reg";
     scalefact = (l_float32)width / (l_float32)w;
     boxa3 = boxaTransform(boxa2, 0, 0, scalefact, scalefact);
     pix1 = boxaDisplayTiled(boxa3, NULL, 1500, 2, 1.0, 0, 3, 2);
-    pixDisplay(pix1, 500, 100);
-    pixWrite("/tmp/lept/boxa/pix2.png", pix1, IFF_PNG);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 13 */
+    pixDisplayWithTitle(pix1, 800, 0, NULL, rp->display);
     pixDestroy(&pix1);
     boxaDestroy(&boxa1);
     boxaDestroy(&boxa2);
+    boxaDestroy(&boxa3);
+
+        /* Input is an unsmoothed and noisy boxa */
+    boxa1 = boxaRead("boxa2.ba");
+    boxa2 = boxaSmoothSequenceMedian(boxa1, 10, L_SUB_ON_LOC_DIFF, 80, 20, 1);
+    boxa3 = boxaSmoothSequenceMedian(boxa1, 10, L_SUB_ON_SIZE_DIFF, 80, 20, 1);
+    boxaPlotSides(boxa1, "initial", NULL, NULL, NULL, NULL, &pix1);
+    boxaPlotSides(boxa2, "side_smoothing", NULL, NULL, NULL, NULL, &pix2);
+    boxaPlotSides(boxa3, "size_smoothing", NULL, NULL, NULL, NULL, &pix3);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 14 */
+    regTestWritePixAndCheck(rp, pix2, IFF_PNG);  /* 15 */
+    regTestWritePixAndCheck(rp, pix3, IFF_PNG);  /* 16 */
+    pixDisplayWithTitle(pix1, 1300, 0, NULL, rp->display);
+    pixDisplayWithTitle(pix2, 1300, 500, NULL, rp->display);
+    pixDisplayWithTitle(pix3, 1300, 1000, NULL, rp->display);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    boxaDestroy(&boxa1);
+    boxaDestroy(&boxa2);
     boxaDestroy(&boxa3);
 
         /* Input is a boxa smoothed with a median window filter */
@@ -138,8 +163,8 @@ static char  mainName[] = "boxa1_reg";
     scalefact = (l_float32)width / (l_float32)w;
     boxa3 = boxaTransform(boxa2, 0, 0, scalefact, scalefact);
     pix1 = boxaDisplayTiled(boxa3, NULL, 1500, 2, 1.0, 0, 3, 2);
-    pixDisplay(pix1, 1000, 100);
-    pixWrite("/tmp/lept/boxa/pix3.png", pix1, IFF_PNG);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 17 */
+    pixDisplayWithTitle(pix1, 1000, 0, NULL, rp->display);
     pixDestroy(&pix1);
     boxaDestroy(&boxa1);
     boxaDestroy(&boxa2);
@@ -153,17 +178,14 @@ static char  mainName[] = "boxa1_reg";
     boxaWrite("/tmp/lept/boxa/boxa1.ba", boxa1);
     boxaWrite("/tmp/lept/boxa/boxa2.ba", boxa2);
     filesAreIdentical("/tmp/lept/boxa/boxa1.ba", "/tmp/lept/boxa/boxa2.ba",
-                      &same); 
-    if (same)
-        fprintf(stderr, "Good: boxes files are identical\n");
-    else
-        fprintf(stderr, "Bad: boxes files differ\n");
+                      &same);
+    regTestCompareValues(rp, 1, same, 0.0);  /* 18 */
     boxaDestroy(&boxa1);
     boxaDestroy(&boxa2);
     lept_free(data1);
     lept_free(data2);
 
-        /* Test pixaDisplayBoxaa() */
+        /* ----------- Test pixaDisplayBoxaa() ------------ */
     pixa1 = pixaReadBoth("showboxes.pac");
     baa1 = boxaaRead("showboxes1.baa");
     baa2 = boxaaTranspose(baa1);
@@ -178,15 +200,16 @@ static char  mainName[] = "boxa1_reg";
         boxaDestroy(&boxa2);
         if (!same) success = FALSE;
     }
-    if (success)
-        fprintf(stderr, "Good: transpose is reversible\n");
-    else
-        fprintf(stderr, "Bad: transpose failed\n");
+        /* Check that the transpose is reversible */
+    regTestCompareValues(rp, 1, success, 0.0);  /* 19 */
     pixa2 = pixaDisplayBoxaa(pixa1, baa2, L_DRAW_RGB, 2);
     pix1 = pixaDisplayTiledInRows(pixa2, 32, 1400, 1.0, 0, 10, 0);
-    pixDisplay(pix1, 0, 600);
+    regTestWritePixAndCheck(rp, pix1, IFF_PNG);  /* 20 */
+    pixDisplayWithTitle(pix1, 0, 600, NULL, rp->display);
     fprintf(stderr, "Writing to: /tmp/lept/boxa/show.pdf\n");
+    l_pdfSetDateAndVersion(FALSE);
     pixaConvertToPdf(pixa2, 75, 1.0, 0, 0, NULL, "/tmp/lept/boxa/show.pdf");
+    regTestCheckFile(rp, "/tmp/lept/boxa/show.pdf");  /* 21 */
     pixDestroy(&pix1);
     pixaDestroy(&pixa1);
     pixaDestroy(&pixa2);
@@ -194,7 +217,7 @@ static char  mainName[] = "boxa1_reg";
     boxaaDestroy(&baa2);
     boxaaDestroy(&baa3);
 
-    return 0;
+    return regTestCleanup(rp);
 }
 
 
