@@ -87,7 +87,7 @@ static l_int32 testcomp_mem(PIX *pixs, PIX **ppixt, l_int32 index,
 static l_int32 test_writemem(PIX *pixs, l_int32 format, char *psfile);
 static PIX *make_24_bpp_pix(PIX *pixs);
 static l_int32 get_header_data(const char *filename, l_int32 true_format);
-static void get_tiff_compression_name(char *buf, l_int32 format);
+static const char *get_tiff_compression_name(l_int32 format);
 
 LEPT_DLL extern const char *ImageFileFormatExtensions[];
 
@@ -334,7 +334,6 @@ L_REGPARAMS  *rp;
 
     /* ---------------- Part 4: Test non-tiff r/w to memory ---------------- */
 
-    pixDisplayWrite(NULL, -1);
     success = (n < 6) ? FALSE : TRUE;
     for (i = 0; i < n; i++) {
         if ((pix = pixaGetPix(pixa, i, L_CLONE)) == NULL) {
@@ -342,7 +341,7 @@ L_REGPARAMS  *rp;
             continue;
         }
         d = pixGetDepth(pix);
-        sprintf(psname, "/tmp/lept/regout/junkps.%d", d);
+        snprintf(psname, sizeof(psname), "/tmp/lept/regout/junkps.%d", d);
         fprintf(stderr, "%d bpp\n", d);
         if (test_writemem(pix, IFF_PNM, NULL)) success = FALSE;
         if (test_writemem(pix, IFF_PS, psname)) success = FALSE;
@@ -485,15 +484,11 @@ part6:
     if (get_header_data(FILE_32BPP_ALPHA, IFF_PNG)) success = FALSE;
 
     pix = pixRead(FILE_8BPP_1);
-    tempname = genTempFilename((const char *)"/tmp/lept/regout",
-                               (const char *)".pnm", 1, 1);
+    tempname = l_makeTempFilename();
     pixWrite(tempname, pix, IFF_PNM);
     if (get_header_data(tempname, IFF_PNM)) success = FALSE;
     pixDestroy(&pix);
-    lept_free(tempname);
     pix = pixRead(FILE_1BPP);
-    tempname = genTempFilename((const char *)"/tmp/lept/regout",
-                               (const char *)".tif", 1, 1);
     pixWrite(tempname, pix, IFF_TIFF_G3);
     if (get_header_data(tempname, IFF_TIFF_G3)) success = FALSE;
     pixWrite(tempname, pix, IFF_TIFF_G4);
@@ -509,6 +504,7 @@ part6:
     pixWrite(tempname, pix, IFF_TIFF);
     if (get_header_data(tempname, IFF_TIFF)) success = FALSE;
     pixDestroy(&pix);
+    lept_rmfile(tempname);
     lept_free(tempname);
 
     if (success)
@@ -664,7 +660,6 @@ PIX       *pixd = NULL;
             fprintf(stderr, "Mem write/read fail for format %d, diff = %5.2f\n",
                     format, diff);
         }
-        pixDisplayWrite(pixd, 1);
     } else {
         pixEqual(pixs, pixd, &same);
         if (!same)
@@ -710,11 +705,11 @@ static l_int32
 get_header_data(const char  *filename,
                 l_int32      true_format)
 {
-char      buf[64];
-l_uint8  *data;
-l_int32   ret1, ret2, format1, format2;
-l_int32   w1, w2, h1, h2, d1, d2, bps1, bps2, spp1, spp2, iscmap1, iscmap2;
-size_t    size1, size2;
+const char *tiff_compression_name = "undefined";
+l_uint8    *data;
+l_int32     ret1, ret2, format1, format2;
+l_int32     w1, w2, h1, h2, d1, d2, bps1, bps2, spp1, spp2, iscmap1, iscmap2;
+size_t      size1, size2;
 
     /* Fail silently if library is not available */
 #if !HAVE_LIBJPEG
@@ -742,11 +737,12 @@ size_t    size1, size2;
         fprintf(stderr, "Error: couldn't read header data: %s\n", filename);
     else {
         if (format1 > IFF_PNG && format1 < IFF_PNM) {
-            get_tiff_compression_name(buf, format1);
+            tiff_compression_name = get_tiff_compression_name(format1);
             fprintf(stderr, "Format data for image %s with format %s:\n"
                 "  nbytes = %lu, size (w, h, d) = (%d, %d, %d)\n"
                 "  bps = %d, spp = %d, iscmap = %d\n",
-                filename, buf, (unsigned long)size1, w1, h1, d1,
+                filename, tiff_compression_name,
+                (unsigned long)size1, w1, h1, d1,
                 bps1, spp1, iscmap1);
         } else {
             fprintf(stderr, "Format data for image %s with format %s:\n"
@@ -775,8 +771,8 @@ size_t    size1, size2;
         if (size1 != size2 || format1 != format2 || w1 != w2 ||
             h1 != h2 || d1 != d2 || bps1 != bps2 || spp1 != spp2 ||
             iscmap1 != iscmap2) {
-            fprintf(stderr, "Incomsistency reading image %s with format %s\n",
-                    filename, buf);
+            fprintf(stderr, "Inconsistency reading image %s with format %s\n",
+                    filename, tiff_compression_name);
             ret2 = 1;
         }
     }
@@ -784,25 +780,25 @@ size_t    size1, size2;
 }
 
 
-static void
-get_tiff_compression_name(char    *buf,
-                          l_int32  format)
+static const char *
+get_tiff_compression_name(l_int32  format)
 {
+    const char *tiff_compression_name = "unknown";
     if (format == IFF_TIFF_G4)
-        sprintf(buf, "tiff_g4");
+        tiff_compression_name = "tiff_g4";
     else if (format == IFF_TIFF_G3)
-        sprintf(buf, "tiff_g3");
+        tiff_compression_name =  "tiff_g3";
     else if (format == IFF_TIFF_ZIP)
-        sprintf(buf, "tiff_zip");
+        tiff_compression_name =  "tiff_zip";
     else if (format == IFF_TIFF_LZW)
-        sprintf(buf, "tiff_lzw");
+        tiff_compression_name =  "tiff_lzw";
     else if (format == IFF_TIFF_RLE)
-        sprintf(buf, "tiff_rle");
+        tiff_compression_name =  "tiff_rle";
     else if (format == IFF_TIFF_PACKBITS)
-        sprintf(buf, "tiff_packbits");
+        tiff_compression_name =  "tiff_packbits";
     else if (format == IFF_TIFF)
-        sprintf(buf, "tiff_uncompressed");
+        tiff_compression_name = "tiff_uncompressed";
     else
         fprintf(stderr, "format %d: not tiff\n", format);
-    return;
+    return tiff_compression_name;
 }
