@@ -36,7 +36,7 @@ static const l_int32 gaussmean1[5] = {20, 40, 60, 80, 60};
 static const l_int32 gaussstdev1[5] = {10, 20, 20, 20, 30};
 static const l_int32 gaussmean2[5] = {220, 200, 140, 180, 150};
 static const l_int32 gaussstdev2[5] = {15, 20, 40, 20, 30};
-static const l_float32 gaussfract1[5] = {0.2, 0.3, 0.1, 0.5, 0.3};
+static const l_float32 gaussfract1[5] = {0.2f, 0.3f, 0.1f, 0.5f, 0.3f};
 static char  buf[256];
 
 static l_int32  GenerateSplitPlot(l_int32 i);
@@ -50,6 +50,7 @@ l_int32  i;
 PIX     *pix;
 PIXA    *pixa;
 
+    setLeptDebugOK(1);
     lept_mkdir("lept/otsu");
     for (i = 0; i < NTests; i++)
         GenerateSplitPlot(i);
@@ -57,11 +58,11 @@ PIXA    *pixa;
        /* Read the results back in ...  */
     pixa = pixaCreate(0);
     for (i = 0; i < NTests; i++) {
-        sprintf(buf, "/tmp/lept/otsu/plot.%d.png", i);
+        snprintf(buf, sizeof(buf), "/tmp/lept/otsu/plot.%d.png", i);
         pix = pixRead(buf);
         pixSaveTiled(pix, pixa, 1.0, 1, 25, 32);
         pixDestroy(&pix);
-        sprintf(buf, "/tmp/lept/otsu/plots.%d.png", i);
+        snprintf(buf, sizeof(buf), "/tmp/lept/otsu/plots.%d.png", i);
         pix = pixRead(buf);
         pixSaveTiled(pix, pixa, 1.0, 0, 25, 32);
         pixDestroy(&pix);
@@ -105,8 +106,8 @@ NUMA      *na1, *na2, *nascore, *nax, *nay;
     numaReplaceNumber(nay, 1, (l_int32)(0.5 * maxnum));
 
         /* Plot the input histogram with the split location */
-    sprintf(buf, "/tmp/lept/otsu/plot.%d", i);
-    sprintf(title, "Plot %d", i);
+    snprintf(buf, sizeof(buf), "/tmp/lept/otsu/plot.%d", i);
+    snprintf(title, sizeof(title), "Plot %d", i);
     gplot = gplotCreate(buf, GPLOT_PNG,
                         "Histogram: mixture of 2 gaussians",
                         "Grayscale value", "Number of pixels");
@@ -118,8 +119,8 @@ NUMA      *na1, *na2, *nascore, *nax, *nay;
     numaDestroy(&na2);
 
         /* Plot the score function */
-    sprintf(buf, "/tmp/lept/otsu/plots.%d", i);
-    sprintf(title, "Plot %d", i);
+    snprintf(buf, sizeof(buf), "/tmp/lept/otsu/plots.%d", i);
+    snprintf(title, sizeof(title), "Plot %d", i);
     gplot = gplotCreate(buf, GPLOT_PNG,
                         "Otsu score function for splitting",
                         "Grayscale value", "Score");
