@@ -37,6 +37,13 @@
  *
  *   If the printer is not specified, this just writes the PostScript
  *   file into /tmp.
+ *
+ *   ***************************************************************
+ *   N.B.  This requires lpr, which is invoked via 'system'.  It could
+ *         pose a security vulnerability if used as a service in a
+ *         production environment.  Consequently, this program should
+ *         only be used for debug and testing.
+ *   ***************************************************************
  */
 
 #include "allheaders.h"
@@ -54,11 +61,18 @@ static char     mainName[] = "printtiff";
 
     if (argc != 2 && argc != 3)
         return ERROR_INT(" Syntax:  printtiff filein [printer]", mainName, 1);
-
     filein = argv[1];
     if (argc == 3)
         printer = argv[2];
 
+    fprintf(stderr,
+         "\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n"
+         "   Warning: this program should only be used for testing,\n"
+         "     and not in a production environment, because of a\n"
+         "      potential vulnerability with the 'system' call.\n"
+         "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n\n");
+
+    setLeptDebugOK(1);
     lept_rm(NULL, TEMP_PS);
     tempfile = genPathname("/tmp", TEMP_PS);
     convertTiffMultipageToPS(filein, tempfile, FILL_FACTOR);
