@@ -1,16 +1,27 @@
 /*====================================================================*
  -  Copyright (C) 2001 Leptonica.  All rights reserved.
- -  This software is distributed in the hope that it will be
- -  useful, but with NO WARRANTY OF ANY KIND.
- -  No author or distributor accepts responsibility to anyone for the
- -  consequences of using this software, or for whether it serves any
- -  particular purpose or works at all, unless he or she says so in
- -  writing.  Everyone is granted permission to copy, modify and
- -  redistribute this source code, for commercial or non-commercial
- -  purposes, with the following restrictions: (1) the origin of this
- -  source code must not be misrepresented; (2) modified versions must
- -  be plainly marked as such; and (3) this notice may not be removed
- -  or altered from any source or modified source distribution.
+ -
+ -  Redistribution and use in source and binary forms, with or without
+ -  modification, are permitted provided that the following conditions
+ -  are met:
+ -  1. Redistributions of source code must retain the above copyright
+ -     notice, this list of conditions and the following disclaimer.
+ -  2. Redistributions in binary form must reproduce the above
+ -     copyright notice, this list of conditions and the following
+ -     disclaimer in the documentation and/or other materials
+ -     provided with the distribution.
+ -
+ -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
+ -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
 /*
@@ -28,8 +39,8 @@
 
 #include "allheaders.h"
 
-main(int    argc,
-     char **argv)
+int main(int    argc,
+         char **argv)
 {
 l_int32       i, j, w, h;
 l_int32       minsum[5] =    { 2, 40, 50, 50, 70};
@@ -88,7 +99,7 @@ L_REGPARAMS  *rp;
         pix32 = pixCreate(w, h, 32);
         pixSetAll(pix32);
         pixPaintThroughMask(pix32, pixt, 0, 0, 0xc0c0c000);
-        pixSaveTiled(pix32, pixad, 1, 1, 30, 32);
+        pixSaveTiled(pix32, pixad, 1.0, 1, 30, 32);
         for (i = 0; i < 5; i++) {
             pixc = pixCopy(NULL, pix32);
             boxa = pixSplitComponentIntoBoxa(pixt, NULL, minsum[i], skipdist[i],
@@ -96,7 +107,7 @@ L_REGPARAMS  *rp;
 /*            boxaWriteStream(stderr, boxa); */
             pixd = pixBlendBoxaRandom(pixc, boxa, 0.4);
             pixRenderBoxaArb(pixd, boxa, 2, 255, 0, 0);
-            pixSaveTiled(pixd, pixad, 1, 0, 30, 32);
+            pixSaveTiled(pixd, pixad, 1.0, 0, 30, 32);
             pixDestroy(&pixd);
             pixDestroy(&pixc);
             boxaDestroy(&boxa);
@@ -114,12 +125,12 @@ L_REGPARAMS  *rp;
 
         /* Put the 8 masks all together, and split 5 ways */
     pixad = pixaCreate(0);
-    pixs = pixaDisplayOnLattice(pixas, 325, 325);
+    pixs = pixaDisplayOnLattice(pixas, 325, 325, NULL, NULL);
     pixGetDimensions(pixs, &w, &h, NULL);
     pix32 = pixCreate(w, h, 32);
     pixSetAll(pix32);
     pixPaintThroughMask(pix32, pixs, 0, 0, 0xc0c0c000);
-    pixSaveTiled(pix32, pixad, 1, 1, 30, 32);
+    pixSaveTiled(pix32, pixad, 1.0, 1, 30, 32);
     for (i = 0; i < 5; i++) {
         pixc = pixCopy(NULL, pix32);
         boxa = pixSplitIntoBoxa(pixs, minsum[i], skipdist[i],
@@ -127,7 +138,7 @@ L_REGPARAMS  *rp;
 /*        boxaWriteStream(stderr, boxa); */
         pixd = pixBlendBoxaRandom(pixc, boxa, 0.4);
         pixRenderBoxaArb(pixd, boxa, 2, 255, 0, 0);
-        pixSaveTiled(pixd, pixad, 1, 0, 30, 32);
+        pixSaveTiled(pixd, pixad, 1.0, 0, 30, 32);
         pixDestroy(&pixd);
         pixDestroy(&pixc);
         boxaDestroy(&boxa);
