@@ -66,6 +66,7 @@
  *           l_int32   boxaPlotSizes()   [for debugging]
  *           BOXA     *boxaFillSequence()
  *    static l_int32   boxaFillAll()
+ *           l_int32   boxaSizeVariation()
  *
  *      Miscellaneous boxa functions
  *           l_int32   boxaGetExtent()
@@ -999,22 +1000,22 @@ BOXA    *boxae, *boxao, *boxalfe, *boxalfo, *boxame, *boxamo, *boxad;
     boxaSplitEvenOdd(boxas, 1, &boxae, &boxao);
     if (debug) {
         lept_mkdir("lept/smooth");
-        boxaWrite("/tmp/lept/smooth/boxae.ba", boxae);
-        boxaWrite("/tmp/lept/smooth/boxao.ba", boxao);
+        boxaWriteDebug("/tmp/lept/smooth/boxae.ba", boxae);
+        boxaWriteDebug("/tmp/lept/smooth/boxao.ba", boxao);
     }
 
     boxalfe = boxaLinearFit(boxae, factor, debug);
     boxalfo = boxaLinearFit(boxao, factor, debug);
     if (debug) {
-        boxaWrite("/tmp/lept/smooth/boxalfe.ba", boxalfe);
-        boxaWrite("/tmp/lept/smooth/boxalfo.ba", boxalfo);
+        boxaWriteDebug("/tmp/lept/smooth/boxalfe.ba", boxalfe);
+        boxaWriteDebug("/tmp/lept/smooth/boxalfo.ba", boxalfo);
     }
 
     boxame = boxaModifyWithBoxa(boxae, boxalfe, subflag, maxdiff, extrapixels);
     boxamo = boxaModifyWithBoxa(boxao, boxalfo, subflag, maxdiff, extrapixels);
     if (debug) {
-        boxaWrite("/tmp/lept/smooth/boxame.ba", boxame);
-        boxaWrite("/tmp/lept/smooth/boxamo.ba", boxamo);
+        boxaWriteDebug("/tmp/lept/smooth/boxame.ba", boxame);
+        boxaWriteDebug("/tmp/lept/smooth/boxamo.ba", boxamo);
     }
 
     boxad = boxaMergeEvenOdd(boxame, boxamo, 1);
@@ -1105,22 +1106,22 @@ BOXA    *boxae, *boxao, *boxamede, *boxamedo, *boxame, *boxamo, *boxad;
     boxaSplitEvenOdd(boxas, 0, &boxae, &boxao);
     if (debug) {
         lept_mkdir("lept/smooth");
-        boxaWrite("/tmp/lept/smooth/boxae.ba", boxae);
-        boxaWrite("/tmp/lept/smooth/boxao.ba", boxao);
+        boxaWriteDebug("/tmp/lept/smooth/boxae.ba", boxae);
+        boxaWriteDebug("/tmp/lept/smooth/boxao.ba", boxao);
     }
 
     boxamede = boxaWindowedMedian(boxae, halfwin, debug);
     boxamedo = boxaWindowedMedian(boxao, halfwin, debug);
     if (debug) {
-        boxaWrite("/tmp/lept/smooth/boxamede.ba", boxamede);
-        boxaWrite("/tmp/lept/smooth/boxamedo.ba", boxamedo);
+        boxaWriteDebug("/tmp/lept/smooth/boxamede.ba", boxamede);
+        boxaWriteDebug("/tmp/lept/smooth/boxamedo.ba", boxamedo);
     }
 
     boxame = boxaModifyWithBoxa(boxae, boxamede, subflag, maxdiff, extrapixels);
     boxamo = boxaModifyWithBoxa(boxao, boxamedo, subflag, maxdiff, extrapixels);
     if (debug) {
-        boxaWrite("/tmp/lept/smooth/boxame.ba", boxame);
-        boxaWrite("/tmp/lept/smooth/boxamo.ba", boxamo);
+        boxaWriteDebug("/tmp/lept/smooth/boxame.ba", boxame);
+        boxaWriteDebug("/tmp/lept/smooth/boxamo.ba", boxamo);
     }
 
     boxad = boxaMergeEvenOdd(boxame, boxamo, 0);
@@ -1249,8 +1250,8 @@ PTA       *ptal, *ptat, *ptar, *ptab;
         L_INFO("# lr reject = %d, # tb reject = %d\n", procName,
                rejectlr, rejecttb);
         lept_mkdir("linfit");
-        boxaWrite("/tmp/linfit/boxalr.ba", boxalr);
-        boxaWrite("/tmp/linfit/boxatb.ba", boxatb);
+        boxaWriteDebug("/tmp/linfit/boxalr.ba", boxalr);
+        boxaWriteDebug("/tmp/linfit/boxatb.ba", boxatb);
     }
 
         /* Extract the valid left and right box sides, along with the box
@@ -1262,10 +1263,10 @@ PTA       *ptal, *ptat, *ptar, *ptab;
     boxaDestroy(&boxatb);
 
     if (debug) {
-        ptaWrite("/tmp/linfit/ptal.pta", ptal, 1);
-        ptaWrite("/tmp/linfit/ptar.pta", ptar, 1);
-        ptaWrite("/tmp/linfit/ptat.pta", ptat, 1);
-        ptaWrite("/tmp/linfit/ptab.pta", ptab, 1);
+        ptaWriteDebug("/tmp/linfit/ptal.pta", ptal, 1);
+        ptaWriteDebug("/tmp/linfit/ptar.pta", ptar, 1);
+        ptaWriteDebug("/tmp/linfit/ptat.pta", ptat, 1);
+        ptaWriteDebug("/tmp/linfit/ptab.pta", ptab, 1);
     }
 
         /* Do a linear LSF fit to the points that are width and height
@@ -2294,6 +2295,97 @@ BOX      *box, *boxt;
 }
 
 
+/*!
+ * \brief   boxaSizeVariation()
+ *
+ * \param[in]    boxa           at least 4 boxes
+ * \param[in]    type           L_SELECT_WIDTH, L_SELECT_HEIGHT
+ * \param[out]   pdel_evenodd   [optional] average absolute value of
+ *                              (even - odd) size pairs
+ * \param[out]   prmsdev_even   [optional] rms deviation of even boxes
+ * \param[out]   prmsdev_odd    [optional] rms deviation of odd boxes
+ * \param[out]   prmsdev_all    [optional] rms deviation of all boxes
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) This gives several measures of the smoothness of either the
+ *          width or height of a sequence of boxes.
+ *      (2) Statistics can be found separately for even and odd boxes.
+ *          Additionally, the average pair-wise difference between
+ *          adjacent even and odd boxes can be returned.
+ *      (3) The use case is bounding boxes for scanned page images,
+ *          where ideally the sizes should have little variance.
+ * </pre>
+ */
+l_int32
+boxaSizeVariation(BOXA       *boxa,
+                  l_int32     type,
+                  l_float32  *pdel_evenodd,
+                  l_float32  *prms_even,
+                  l_float32  *prms_odd,
+                  l_float32  *prms_all)
+{
+l_int32    n, ne, no, nmin, vale, valo, i;
+l_float32  sum;
+BOXA      *boxae, *boxao;
+NUMA      *nae, *nao, *na_all;
+
+    PROCNAME("boxaSizeVariation");
+
+    if (pdel_evenodd) *pdel_evenodd = 0.0;
+    if (prms_even) *prms_even = 0.0;
+    if (prms_odd) *prms_odd = 0.0;
+    if (prms_all) *prms_all = 0.0;
+    if (!boxa)
+        return ERROR_INT("boxa not defined", procName, 1);
+    if (type != L_SELECT_WIDTH && type != L_SELECT_HEIGHT)
+        return ERROR_INT("invalid type", procName, 1);
+    if (!pdel_evenodd && !prms_even && !prms_odd && !prms_all)
+        return ERROR_INT("nothing to do", procName, 1);
+    n = boxaGetCount(boxa);
+    if (n < 4)
+        return ERROR_INT("too few boxes", procName, 1);
+
+    boxaSplitEvenOdd(boxa, 0, &boxae, &boxao);
+    if (type == L_SELECT_WIDTH) {
+        boxaGetSizes(boxae, &nae, NULL);
+        boxaGetSizes(boxao, &nao, NULL);
+        boxaGetSizes(boxa, &na_all, NULL);
+    } else {   /* L_SELECT_HEIGHT) */
+        boxaGetSizes(boxae, NULL, &nae);
+        boxaGetSizes(boxao, NULL, &nao);
+        boxaGetSizes(boxa, NULL, &na_all);
+    }
+    ne = numaGetCount(nae);
+    no = numaGetCount(nao);
+    nmin = L_MIN(ne, no);
+
+    if (pdel_evenodd) {
+        sum = 0.0;
+        for (i = 0; i < nmin; i++) {
+            numaGetIValue(nae, i, &vale);
+            numaGetIValue(nao, i, &valo);
+            sum += L_ABS(vale - valo);
+        }
+        *pdel_evenodd = sum / nmin;
+    }
+    if (prms_even)
+        numaSimpleStats(nae, 0, 0, NULL, NULL, prms_even);
+    if (prms_odd)
+        numaSimpleStats(nao, 0, 0, NULL, NULL, prms_odd);
+    if (prms_all)
+        numaSimpleStats(na_all, 0, 0, NULL, NULL, prms_all);
+
+    boxaDestroy(&boxae);
+    boxaDestroy(&boxao);
+    numaDestroy(&nae);
+    numaDestroy(&nao);
+    numaDestroy(&na_all);
+    return 0;
+}
+
+
 /*---------------------------------------------------------------------*
  *                    Miscellaneous Boxa functions                     *
  *---------------------------------------------------------------------*/
