@@ -24,8 +24,9 @@
  -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
-/*
- *  pixalloc.c
+/*!
+ * \file pixalloc.c
+ * <pre>
  *
  *      Custom memory storage with allocator and deallocator
  *
@@ -37,6 +38,7 @@
  *          l_int32       pmsGetLevelForAlloc()
  *          l_int32       pmsGetLevelForDealloc()
  *          void          pmsLogInfo()
+ * </pre>
  */
 
 #include "allheaders.h"
@@ -107,27 +109,27 @@
  *  will free them.
  */
 
-
+/*! Pix memory storage */
 struct PixMemoryStore
 {
-    struct L_Ptraa  *paa;          /* Holds ptrs to allocated memory        */
-    size_t           minsize;      /* Pix smaller than this (in bytes)      */
-                                   /* are allocated dynamically             */
-    size_t           smallest;     /* Smallest mem (in bytes) alloc'd       */
-    size_t           largest;      /* Larest mem (in bytes) alloc'd         */
-    size_t           nbytes;       /* Size of allocated block w/ all chunks */
-    l_int32          nlevels;      /* Num of power-of-2 sizes pre-alloc'd   */
-    size_t          *sizes;        /* Mem sizes at each power-of-2 level    */
-    l_int32         *allocarray;   /* Number of mem alloc'd at each size    */
-    l_uint32        *baseptr;      /* ptr to allocated array                */
-    l_uint32        *maxptr;       /* ptr just beyond allocated memory      */
-    l_uint32       **firstptr;     /* array of ptrs to first chunk in size  */
-    l_int32         *memused;      /* log: total # of pix used (by level)   */
-    l_int32         *meminuse;     /* log: # of pix in use (by level)       */
-    l_int32         *memmax;       /* log: max # of pix in use (by level)   */
-    l_int32         *memempty;     /* log: # of pix alloc'd because         */
-                                   /*      the store was empty (by level)   */
-    char            *logfile;      /* log: set to null if no logging        */
+    struct L_Ptraa  *paa;        /*!< Holds ptrs to allocated memory        */
+    size_t           minsize;    /*!< Pix smaller than this (in bytes)      */
+                                 /*!< are allocated dynamically             */
+    size_t           smallest;   /*!< Smallest mem (in bytes) alloc'd       */
+    size_t           largest;    /*!< Larest mem (in bytes) alloc'd         */
+    size_t           nbytes;     /*!< Size of allocated block w/ all chunks */
+    l_int32          nlevels;    /*!< Num of power-of-2 sizes pre-alloc'd   */
+    size_t          *sizes;      /*!< Mem sizes at each power-of-2 level    */
+    l_int32         *allocarray; /*!< Number of mem alloc'd at each size    */
+    l_uint32        *baseptr;    /*!< ptr to allocated array                */
+    l_uint32        *maxptr;     /*!< ptr just beyond allocated memory      */
+    l_uint32       **firstptr;   /*!< array of ptrs to first chunk in size  */
+    l_int32         *memused;    /*!< log: total # of pix used (by level)   */
+    l_int32         *meminuse;   /*!< log: # of pix in use (by level)       */
+    l_int32         *memmax;     /*!< log: max # of pix in use (by level)   */
+    l_int32         *memempty;   /*!< log: # of pix alloc'd because         */
+                                 /*!<      the store was empty (by level)   */
+    char            *logfile;    /*!< log: set to null if no logging        */
 };
 typedef struct PixMemoryStore   L_PIX_MEM_STORE;
 
@@ -135,21 +137,22 @@ static L_PIX_MEM_STORE  *CustomPMS = NULL;
 
 
 /*!
- *  pmsCreate()
+ * \brief   pmsCreate()
  *
- *      Input:  minsize (of data chunk that can be supplied by pms)
- *              smallest (bytes of the smallest pre-allocated data chunk.
+ * \param[in]    minsize of data chunk that can be supplied by pms
+ * \param[in]    smallest bytes of the smallest pre-allocated data chunk.
  *              numalloc (array with the number of data chunks for each
- *                        size that are in the memory store)
- *              logfile (use for debugging; null otherwise)
- *      Return: 0 if OK, 1 on error
+ *                        size that are in the memory store
+ * \param[in]    logfile use for debugging; null otherwise
+ * \return  0 if OK, 1 on error
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This computes the size of the block of memory required
  *          and allocates it.  Each chunk starts on a 32-bit word boundary.
- *          The chunk sizes are in powers of 2, starting at @smallest,
+ *          The chunk sizes are in powers of 2, starting at %smallest,
  *          and the number of levels and chunks at each level is
- *          specified by @numalloc.
+ *          specified by %numalloc.
  *      (2) This is intended to manage the image data for a small number
  *          of relatively large pix.  The system malloc is expected to
  *          handle very large numbers of small chunks efficiently.
@@ -159,6 +162,7 @@ static L_PIX_MEM_STORE  *CustomPMS = NULL;
  *      (4) The pms struct is stored in a static global, so this function
  *          is not thread-safe.  When used, there must be only one thread
  *          per process.
+ * </pre>
  */
 l_int32
 pmsCreate(size_t       minsize,
@@ -184,7 +188,8 @@ L_PTRAA          *paa;
     if (nchunks > 1000.0)
         L_WARNING("There are %.0f chunks\n", procName, nchunks);
 
-    if ((pms = (L_PIX_MEM_STORE *)CALLOC(1, sizeof(L_PIX_MEM_STORE))) == NULL)
+    if ((pms = (L_PIX_MEM_STORE *)LEPT_CALLOC(1, sizeof(L_PIX_MEM_STORE)))
+        == NULL)
         return ERROR_INT("pms not made", procName, 1);
     CustomPMS = pms;
 
@@ -195,7 +200,7 @@ L_PTRAA          *paa;
     nlevels = numaGetCount(numalloc);
     pms->nlevels = nlevels;
 
-    if ((sizes = (size_t *)CALLOC(nlevels, sizeof(size_t))) == NULL)
+    if ((sizes = (size_t *)LEPT_CALLOC(nlevels, sizeof(size_t))) == NULL)
         return ERROR_INT("sizes not made", procName, 1);
     pms->sizes = sizes;
     if (smallest % 4 != 0)
@@ -215,11 +220,13 @@ L_PTRAA          *paa;
         nbytes += alloca[i] * sizes[i];
     pms->nbytes = nbytes;
 
-    if ((baseptr = (l_uint32 *)CALLOC(nbytes / 4, sizeof(l_uint32))) == NULL)
+    if ((baseptr = (l_uint32 *)LEPT_CALLOC(nbytes / 4, sizeof(l_uint32)))
+        == NULL)
         return ERROR_INT("calloc fail for baseptr", procName, 1);
     pms->baseptr = baseptr;
     pms->maxptr = baseptr + nbytes / 4;  /* just beyond the memory store */
-    if ((firstptr = (l_uint32 **)CALLOC(nlevels, sizeof(l_uint32 *))) == NULL)
+    if ((firstptr = (l_uint32 **)LEPT_CALLOC(nlevels, sizeof(l_uint32 *)))
+        == NULL)
         return ERROR_INT("calloc fail for firstptr", procName, 1);
     pms->firstptr = firstptr;
 
@@ -236,10 +243,10 @@ L_PTRAA          *paa;
     }
 
     if (logfile) {
-        pms->memused = (l_int32 *)CALLOC(nlevels, sizeof(l_int32));
-        pms->meminuse = (l_int32 *)CALLOC(nlevels, sizeof(l_int32));
-        pms->memmax = (l_int32 *)CALLOC(nlevels, sizeof(l_int32));
-        pms->memempty = (l_int32 *)CALLOC(nlevels, sizeof(l_int32));
+        pms->memused = (l_int32 *)LEPT_CALLOC(nlevels, sizeof(l_int32));
+        pms->meminuse = (l_int32 *)LEPT_CALLOC(nlevels, sizeof(l_int32));
+        pms->memmax = (l_int32 *)LEPT_CALLOC(nlevels, sizeof(l_int32));
+        pms->memempty = (l_int32 *)LEPT_CALLOC(nlevels, sizeof(l_int32));
         pms->logfile = stringNew(logfile);
     }
 
@@ -248,14 +255,13 @@ L_PTRAA          *paa;
 
 
 /*!
- *  pmsDestroy()
+ * \brief   pmsDestroy()
  *
- *      Input:  (none)
- *      Return: void
- *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) Important: call this function at the end of the program, after
  *          the last pix has been destroyed.
+ * </pre>
  */
 void
 pmsDestroy()
@@ -266,38 +272,40 @@ L_PIX_MEM_STORE  *pms;
         return;
 
     ptraaDestroy(&pms->paa, FALSE, FALSE);  /* don't touch the ptrs */
-    FREE(pms->baseptr);  /* free the memory */
+    LEPT_FREE(pms->baseptr);  /* free the memory */
 
     if (pms->logfile) {
         pmsLogInfo();
-        FREE(pms->logfile);
-        FREE(pms->memused);
-        FREE(pms->meminuse);
-        FREE(pms->memmax);
-        FREE(pms->memempty);
+        LEPT_FREE(pms->logfile);
+        LEPT_FREE(pms->memused);
+        LEPT_FREE(pms->meminuse);
+        LEPT_FREE(pms->memmax);
+        LEPT_FREE(pms->memempty);
     }
 
-    FREE(pms->sizes);
-    FREE(pms->allocarray);
-    FREE(pms->firstptr);
-    FREE(pms);
+    LEPT_FREE(pms->sizes);
+    LEPT_FREE(pms->allocarray);
+    LEPT_FREE(pms->firstptr);
+    LEPT_FREE(pms);
     CustomPMS = NULL;
     return;
 }
 
 
 /*!
- *  pmsCustomAlloc()
+ * \brief   pmsCustomAlloc()
  *
- *      Input: nbytes (min number of bytes in the chunk to be retrieved)
- *      Return: data (ptr to chunk)
+ * \param[in]   nbytes min number of bytes in the chunk to be retrieved
+ * \return  data ptr to chunk
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This attempts to find a suitable pre-allocated chunk.
  *          If not found, it dynamically allocates the chunk.
  *      (2) If logging is turned on, the allocations that are not taken
  *          from the memory store, and are at least as large as the
  *          minimum size the store can handle, are logged to file.
+ * </pre>
  */
 void *
 pmsCustomAlloc(size_t  nbytes)
@@ -338,10 +346,10 @@ L_PTRA           *pa;
 
 
 /*!
- *  pmsCustomDealloc()
+ * \brief   pmsCustomDealloc()
  *
- *      Input: data (to be freed or returned to the storage)
- *      Return: void
+ * \param[in]   data to be freed or returned to the storage
+ * \return  void
  */
 void
 pmsCustomDealloc(void  *data)
@@ -363,7 +371,7 @@ L_PTRA           *pa;
     }
 
     if (level < 0) {  /* no logging; just free the data */
-        FREE(data);
+        LEPT_FREE(data);
     } else {  /* return the data to the store */
         pa = ptraaGetPtra(pms->paa, level, L_HANDLE_ONLY);
         ptraAdd(pa, data);
@@ -376,12 +384,13 @@ L_PTRA           *pa;
 
 
 /*!
- *  pmsGetAlloc()
+ * \brief   pmsGetAlloc()
  *
- *      Input:  nbytes
- *      Return: data
+ * \param[in]    nbytes
+ * \return  data
  *
- *  Notes:
+ * <pre>
+ * Notes:
  *      (1) This is called when a request for pix data cannot be
  *          obtained from the preallocated memory store.  After use it
  *          is freed like normal memory.
@@ -391,6 +400,7 @@ L_PTRA           *pa;
  *          The C99 platform-independent format specifier for size_t is %zu,
  *          but windows hasn't conformed, so we are forced to go back to
  *          C89, use %lu, and cast to get platform-independence.  Ugh.
+ * </pre>
  */
 void *
 pmsGetAlloc(size_t  nbytes)
@@ -404,7 +414,7 @@ L_PIX_MEM_STORE  *pms;
     if ((pms = CustomPMS) == NULL)
         return (void *)ERROR_PTR("pms not defined", procName, NULL);
 
-    if ((data = (void *)CALLOC(nbytes, sizeof(char))) == NULL)
+    if ((data = (void *)LEPT_CALLOC(nbytes, sizeof(char))) == NULL)
         return (void *)ERROR_PTR("data not made", procName, NULL);
     if (pms->logfile && nbytes >= pms->smallest) {
         fp = fopenWriteStream(pms->logfile, "a");
@@ -417,11 +427,11 @@ L_PIX_MEM_STORE  *pms;
 
 
 /*!
- *  pmsGetLevelForAlloc()
+ * \brief   pmsGetLevelForAlloc()
  *
- *      Input: nbytes (min number of bytes in the chunk to be retrieved)
- *             &level (<return>; -1 if either too small or too large)
- *      Return: 0 if OK, 1 on error
+ * \param[in]   nbytes min number of bytes in the chunk to be retrieved
+ * \param[out]  plevel  -1 if either too small or too large
+ * \return  0 if OK, 1 on error
  */
 l_int32
 pmsGetLevelForAlloc(size_t    nbytes,
@@ -455,12 +465,12 @@ L_PIX_MEM_STORE  *pms;
 
 
 /*!
- *  pmsGetLevelForDealloc()
+ * \brief   pmsGetLevelForDealloc()
  *
- *      Input: data (ptr to memory chunk)
- *             &level (<return> level in memory store; -1 if allocated
- *                     outside the store)
- *      Return: 0 if OK, 1 on error
+ * \param[in]   data ptr to memory chunk
+ * \param[out]  plevel level in memory store; -1 if allocated
+ *                     outside the store
+ * \return  0 if OK, 1 on error
  */
 l_int32
 pmsGetLevelForDealloc(void     *data,
@@ -495,10 +505,7 @@ L_PIX_MEM_STORE  *pms;
 
 
 /*!
- *  pmsLogInfo()
- *
- *      Input:  (none)
- *      Return: void
+ * \brief   pmsLogInfo()
  */
 void
 pmsLogInfo()
