@@ -37,6 +37,9 @@
 
  *      Pixcomp accessors
  *           l_int32   pixcompGetDimensions()
+ *           l_int32   pixcompGetParameters()
+ *
+ *      Pixcomp compression selection
  *           l_int32   pixcompDetermineFormat()
  *
  *      Pixcomp conversion to Pix
@@ -88,11 +91,14 @@
  *      Conversion to pdf
  *           l_int32   pixacompConvertToPdf()
  *           l_int32   pixacompConvertToPdfData()
+ *           l_int32   pixacompFastConvertToPdfData()
  *
  *      Output for debugging
  *           l_int32   pixacompWriteStreamInfo()
  *           l_int32   pixcompWriteStreamInfo()
  *           PIX      *pixacompDisplayTiledAndScaled()
+ *           l_int32   pixacompWriteFiles()
+ *           l_int32   pixcompWriteFile()
  *
  *   The Pixacomp is an array of Pixcomp, where each Pixcomp is a compressed
  *   string of the image.  We don't use reference counting here.
@@ -104,7 +110,8 @@
  *   The compression type can be either specified or defaulted.
  *   If specified and it is not possible to compress (for example,
  *   you specify a jpeg on a 1 bpp image or one with a colormap),
- *   the compression type defaults to png.
+ *   the compression type defaults to png.  The jpeg compression quality
+ *   can be specified using l_setJpegQuality(); otherwise the default is 75.
  *
  *   The serialized version of the Pixacomp is similar to that for
  *   a Pixa, except that each Pixcomp can be compressed by one of
@@ -150,8 +157,10 @@ static const l_int32  INITIAL_PTR_ARRAYSIZE = 20;   /* n'import quoi */
 extern l_int32 NumImageFileFormatExtensions;
 extern const char *ImageFileFormatExtensions[];
 
-    /* Static function */
+    /* Static functions */
 static l_int32 pixacompExtendArray(PIXAC *pixac);
+static l_int32 pixcompFastConvertToPdfData(PIXC *pixc, const char *title,
+                                           l_uint8 **pdata, size_t *pnbytes);
 
 
 /*---------------------------------------------------------------------*
@@ -168,6 +177,8 @@ static l_int32 pixacompExtendArray(PIXAC *pixac);
  * Notes:
  *      (1) Use %comptype == IFF_DEFAULT to have the compression
  *          type automatically determined.
+ *      (2) To compress jpeg with a quality other than the default (75), use
+ *             l_jpegSetQuality()
  * </pre>
  */
 PIXC *
@@ -431,6 +442,35 @@ pixcompGetDimensions(PIXC     *pixc,
 }
 
 
+/*!
+ * \brief   pixcompGetParameters()
+ *
+ * \param[in]    pixc
+ * \param[out]   pxres, pyres, pcomptype, pcmapflag [all optional]
+ * \return  0 if OK, 1 on error
+ */
+l_int32
+pixcompGetParameters(PIXC     *pixc,
+                     l_int32  *pxres,
+                     l_int32  *pyres,
+                     l_int32  *pcomptype,
+                     l_int32  *pcmapflag)
+{
+    PROCNAME("pixcompGetParameters");
+
+    if (!pixc)
+        return ERROR_INT("pixc not defined", procName, 1);
+    if (pxres) *pxres = pixc->xres;
+    if (pyres) *pyres = pixc->yres;
+    if (pcomptype) *pcomptype = pixc->comptype;
+    if (pcmapflag) *pcmapflag = pixc->cmapflag;
+    return 0;
+}
+
+
+/*---------------------------------------------------------------------*
+ *                    Pixcomp compression selection                    *
+ *---------------------------------------------------------------------*/
 /*!
  * \brief   pixcompDetermineFormat()
  *
@@ -673,6 +713,8 @@ PIXAC   *pixac;
  *          for a 1, 2 or 4 bpp pix, or a pix with a colormap),
  *          in which case we use the default (assumed best) compression.
  *      (2) %accesstype is used to extract a boxa from %pixa.
+ *      (3) To compress jpeg with a quality other than the default (75), use
+ *             l_jpegSetQuality()
  * </pre>
  */
 PIXAC *
@@ -1900,6 +1942,10 @@ FILE    *fp;
  *          all images to be compressed with that type.  Use 0 to have
  *          the type determined for each image based on depth and whether
  *          or not it has a colormap.
+ *      (5) If all images are jpeg compressed, don't require scaling
+ *          and have the same resolution, it is much faster to skip
+ *          transcoding with pixacompFastConvertToPdfData(), and then
+ *          write the data out to file.
  * </pre>
  */
 l_int32
@@ -2047,6 +2093,139 @@ L_PTRA   *pa_data;
 }
 
 
+/*!
+ * \brief   pixacompFastConvertToPdfData()
+ *
+ * \param[in]    pixac containing images all at the same resolution
+ * \param[in]    res input resolution of all images
+ * \param[in]    title [optional] pdf title
+ * \param[out]   pdata output pdf data (of all images
+ * \param[out]   pnbytes size of output pdf data
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) This generates the pdf without transcoding if all the
+ *          images in %pixac are compressed with jpeg.
+ *          Images not jpeg compressed are skipped.
+ *      (2) It assumes all images have the same resolution, and that
+ *          the resolution embedded in each jpeg file is correct.
+ * </pre>
+ */
+l_int32
+pixacompFastConvertToPdfData(PIXAC       *pixac,
+                             const char  *title,
+                             l_uint8    **pdata,
+                             size_t      *pnbytes)
+{
+l_uint8  *imdata;
+l_int32   i, n, ret, comptype;
+size_t    imbytes;
+L_BYTEA  *ba;
+PIXC     *pixc;
+L_PTRA   *pa_data;
+
+    PROCNAME("pixacompFastConvertToPdfData");
+
+    if (!pdata)
+        return ERROR_INT("&data not defined", procName, 1);
+    *pdata = NULL;
+    if (!pnbytes)
+        return ERROR_INT("&nbytes not defined", procName, 1);
+    *pnbytes = 0;
+    if (!pixac)
+        return ERROR_INT("pixac not defined", procName, 1);
+
+        /* Generate all the encoded pdf strings */
+    n = pixacompGetCount(pixac);
+    pa_data = ptraCreate(n);
+    for (i = 0; i < n; i++) {
+        if ((pixc = pixacompGetPixcomp(pixac, i, L_NOCOPY)) == NULL) {
+            L_ERROR("pixc[%d] not retrieved\n", procName, i);
+            continue;
+        }
+        pixcompGetParameters(pixc, NULL, NULL, &comptype, NULL);
+        if (comptype != IFF_JFIF_JPEG) {
+            L_ERROR("pixc[%d] not jpeg compressed\n", procName, i);
+            continue;
+        }
+        ret = pixcompFastConvertToPdfData(pixc, title, &imdata, &imbytes);
+        if (ret) {
+            L_ERROR("pdf encoding failed for pixc[%d]\n", procName, i);
+            continue;
+        }
+        ba = l_byteaInitFromMem(imdata, imbytes);
+        LEPT_FREE(imdata);
+        ptraAdd(pa_data, ba);
+    }
+    ptraGetActualCount(pa_data, &n);
+    if (n == 0) {
+        L_ERROR("no pdf files made\n", procName);
+        ptraDestroy(&pa_data, FALSE, FALSE);
+        return 1;
+    }
+
+        /* Concatenate them */
+    ret = ptraConcatenatePdfToData(pa_data, NULL, pdata, pnbytes);
+
+        /* Clean up */
+    ptraGetActualCount(pa_data, &n);  /* recalculate in case it changes */
+    for (i = 0; i < n; i++) {
+        ba = (L_BYTEA *)ptraRemove(pa_data, i, L_NO_COMPACTION);
+        l_byteaDestroy(&ba);
+    }
+    ptraDestroy(&pa_data, FALSE, FALSE);
+    return ret;
+}
+
+
+/*!
+ * \brief   pixcompFastConvertToPdfData()
+ *
+ * \param[in]    pixc   containing images all at the same resolution
+ * \param[in]    title [optional] pdf title
+ * \param[out]   pdata output pdf data (of all images
+ * \param[out]   pnbytes size of output pdf data
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) This generates the pdf without transcoding.
+ *      (2) It assumes all images are jpeg encoded, have the same
+ *          resolution, and that the resolution embedded in each
+ *          jpeg file is correct.  (It is transferred to the pdf
+ *          via the cid.)
+ * </pre>
+ */
+static l_int32
+pixcompFastConvertToPdfData(PIXC        *pixc,
+                            const char  *title,
+                            l_uint8    **pdata,
+                            size_t      *pnbytes)
+{
+l_uint8      *data;
+L_COMP_DATA  *cid;
+
+    PROCNAME("pixacompFastConvertToPdfData");
+
+    if (!pdata)
+        return ERROR_INT("&data not defined", procName, 1);
+    *pdata = NULL;
+    if (!pnbytes)
+        return ERROR_INT("&nbytes not defined", procName, 1);
+    *pnbytes = 0;
+    if (!pixc)
+        return ERROR_INT("pixc not defined", procName, 1);
+
+        /* Make a copy of the data */
+    data = l_binaryCopy(pixc->data, pixc->size);
+    cid = l_generateJpegDataMem(data, pixc->size, 0);
+
+        /* Note: cid is destroyed, along with data, by this function */
+    return cidConvertToPdfData(cid, title, pdata, pnbytes);
+}
+
+
 /*--------------------------------------------------------------------*
  *                        Output for debugging                        *
  *--------------------------------------------------------------------*/
@@ -2184,3 +2363,69 @@ PIXA  *pixa;
     return pixd;
 }
 
+
+/*!
+ * \brief   pixacompWriteFiles()
+ *
+ * \param[in]    pixac
+ * \param[in]    subdir (subdirectory of /tmp)
+ * \return  0 if OK, 1 on error
+ */
+l_int32
+pixacompWriteFiles(PIXAC       *pixac,
+                   const char  *subdir)
+{
+char     buf[128];
+l_int32  i, n;
+PIXC    *pixc;
+
+    PROCNAME("pixacompWriteFiles");
+
+    if (!pixac)
+        return ERROR_INT("pixac not defined", procName, 1);
+
+    if (lept_mkdir(subdir) > 0)
+        return ERROR_INT("invalid subdir", procName, 1);
+
+    n = pixacompGetCount(pixac);
+    for (i = 0; i < n; i++) {
+        pixc = pixacompGetPixcomp(pixac, i, L_NOCOPY);
+        snprintf(buf, sizeof(buf), "/tmp/%s/%03d", subdir, i);
+        pixcompWriteFile(buf, pixc);
+    }
+    return 0;
+}
+
+extern const char *ImageFileFormatExtensions[];
+
+/*!
+ * \brief   pixcompWriteFile()
+ *
+ * \param[in]    rootname
+ * \param[in]    pixc
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) The compressed data is written to file, and the filename is
+ *          generated by appending the format extension to %rootname.
+ * </pre>
+ */
+l_int32
+pixcompWriteFile(const char  *rootname,
+                 PIXC        *pixc)
+{
+char   buf[128];
+
+    PROCNAME("pixcompWriteFile");
+
+    if (!pixc)
+        return ERROR_INT("pixc not defined", procName, 1);
+
+    snprintf(buf, sizeof(buf), "%s.%s", rootname,
+             ImageFileFormatExtensions[pixc->comptype]);
+    l_binaryWrite(buf, "w", pixc->data, pixc->size);
+    return 0;
+}
+
+
