@@ -59,6 +59,7 @@
  *           PTA            *ptaRead()
  *           PTA            *ptaReadStream()
  *           PTA            *ptaReadMem()
+ *           l_int32         ptaWriteDebug()
  *           l_int32         ptaWrite()
  *           l_int32         ptaWriteStream()
  *           l_int32         ptaWriteMem()
@@ -121,16 +122,17 @@ PTA  *pta;
     if (n <= 0)
         n = INITIAL_PTR_ARRAYSIZE;
 
-    if ((pta = (PTA *)LEPT_CALLOC(1, sizeof(PTA))) == NULL)
-        return (PTA *)ERROR_PTR("pta not made", procName, NULL);
+    pta = (PTA *)LEPT_CALLOC(1, sizeof(PTA));
     pta->n = 0;
     pta->nalloc = n;
     ptaChangeRefcount(pta, 1);  /* sets to 1 */
 
-    if ((pta->x = (l_float32 *)LEPT_CALLOC(n, sizeof(l_float32))) == NULL)
-        return (PTA *)ERROR_PTR("x array not made", procName, NULL);
-    if ((pta->y = (l_float32 *)LEPT_CALLOC(n, sizeof(l_float32))) == NULL)
-        return (PTA *)ERROR_PTR("y array not made", procName, NULL);
+    pta->x = (l_float32 *)LEPT_CALLOC(n, sizeof(l_float32));
+    pta->y = (l_float32 *)LEPT_CALLOC(n, sizeof(l_float32));
+    if (!pta->x || !pta->y) {
+        ptaDestroy(&pta);
+        return (PTA *)ERROR_PTR("x and y arrays not both made", procName, NULL);
+    }
 
     return pta;
 }
@@ -668,15 +670,13 @@ PTA   *pta;
 
     if (!filename)
         return (PTA *)ERROR_PTR("filename not defined", procName, NULL);
+
     if ((fp = fopenReadStream(filename)) == NULL)
         return (PTA *)ERROR_PTR("stream not opened", procName, NULL);
-
-    if ((pta = ptaReadStream(fp)) == NULL) {
-        fclose(fp);
-        return (PTA *)ERROR_PTR("pta not read", procName, NULL);
-    }
-
+    pta = ptaReadStream(fp);
     fclose(fp);
+    if (!pta)
+        return (PTA *)ERROR_PTR("pta not read", procName, NULL);
     return pta;
 }
 
@@ -690,7 +690,7 @@ PTA   *pta;
 PTA *
 ptaReadStream(FILE  *fp)
 {
-char       typestr[128];
+char       typestr[128];  /* hardcoded below in fscanf */
 l_int32    i, n, ix, iy, type, version;
 l_float32  x, y;
 PTA       *pta;
@@ -704,7 +704,7 @@ PTA       *pta;
         return (PTA *)ERROR_PTR("not a pta file", procName, NULL);
     if (version != PTA_VERSION_NUMBER)
         return (PTA *)ERROR_PTR("invalid pta version", procName, NULL);
-    if (fscanf(fp, " Number of pts = %d; format = %s\n", &n, typestr) != 2)
+    if (fscanf(fp, " Number of pts = %d; format = %127s\n", &n, typestr) != 2)
         return (PTA *)ERROR_PTR("not a pta file", procName, NULL);
     if (!strcmp(typestr, "float"))
         type = 0;
@@ -715,12 +715,16 @@ PTA       *pta;
         return (PTA *)ERROR_PTR("pta not made", procName, NULL);
     for (i = 0; i < n; i++) {
         if (type == 0) {  /* data is float */
-            if (fscanf(fp, "   (%f, %f)\n", &x, &y) != 2)
+            if (fscanf(fp, "   (%f, %f)\n", &x, &y) != 2) {
+                ptaDestroy(&pta);
                 return (PTA *)ERROR_PTR("error reading floats", procName, NULL);
+            }
             ptaAddPt(pta, x, y);
         } else {   /* data is integer */
-            if (fscanf(fp, "   (%d, %d)\n", &ix, &iy) != 2)
+            if (fscanf(fp, "   (%d, %d)\n", &ix, &iy) != 2) {
+                ptaDestroy(&pta);
                 return (PTA *)ERROR_PTR("error reading ints", procName, NULL);
+            }
             ptaAddPt(pta, ix, iy);
         }
     }
@@ -757,6 +761,39 @@ PTA   *pta;
 }
 
 
+/*!
+ * \brief   ptaWriteDebug()
+ *
+ * \param[in]    filename
+ * \param[in]    pta
+ * \param[in]    type  0 for float values; 1 for integer values
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) Debug version, intended for use in the library when writing
+ *          to files in a temp directory with names that are compiled in.
+ *          This is used instead of ptaWrite() for all such library calls.
+ *      (2) The global variable LeptDebugOK defaults to 0, and can be set
+ *          or cleared by the function setLeptDebugOK().
+ * </pre>
+ */
+l_int32
+ptaWriteDebug(const char  *filename,
+              PTA         *pta,
+              l_int32      type)
+{
+    PROCNAME("ptaWriteDebug");
+
+    if (LeptDebugOK) {
+        return ptaWrite(filename, pta, type);
+    } else {
+        L_INFO("write to named temp file %s is disabled\n", procName, filename);
+        return 0;
+    }
+}
+
+
 /*!
  * \brief   ptaWrite()
  *
@@ -770,7 +807,8 @@ ptaWrite(const char  *filename,
          PTA         *pta,
          l_int32      type)
 {
-FILE  *fp;
+l_int32  ret;
+FILE    *fp;
 
     PROCNAME("ptaWrite");
 
@@ -781,10 +819,10 @@ FILE  *fp;
 
     if ((fp = fopenWriteStream(filename, "w")) == NULL)
         return ERROR_INT("stream not opened", procName, 1);
-    if (ptaWriteStream(fp, pta, type))
-        return ERROR_INT("pta not written to stream", procName, 1);
+    ret = ptaWriteStream(fp, pta, type);
     fclose(fp);
-
+    if (ret)
+        return ERROR_INT("pta not written to stream", procName, 1);
     return 0;
 }
 
@@ -911,10 +949,10 @@ PTAA  *ptaa;
         return (PTAA *)ERROR_PTR("ptaa not made", procName, NULL);
     ptaa->n = 0;
     ptaa->nalloc = n;
-
-    if ((ptaa->pta = (PTA **)LEPT_CALLOC(n, sizeof(PTA *))) == NULL)
+    if ((ptaa->pta = (PTA **)LEPT_CALLOC(n, sizeof(PTA *))) == NULL) {
+        ptaaDestroy(&ptaa);
         return (PTAA *)ERROR_PTR("pta ptrs not made", procName, NULL);
-
+    }
     return ptaa;
 }
 
@@ -1278,15 +1316,13 @@ PTAA  *ptaa;
 
     if (!filename)
         return (PTAA *)ERROR_PTR("filename not defined", procName, NULL);
+
     if ((fp = fopenReadStream(filename)) == NULL)
         return (PTAA *)ERROR_PTR("stream not opened", procName, NULL);
-
-    if ((ptaa = ptaaReadStream(fp)) == NULL) {
-        fclose(fp);
-        return (PTAA *)ERROR_PTR("ptaa not read", procName, NULL);
-    }
-
+    ptaa = ptaaReadStream(fp);
     fclose(fp);
+    if (!ptaa)
+        return (PTAA *)ERROR_PTR("ptaa not read", procName, NULL);
     return ptaa;
 }
 
@@ -1319,8 +1355,10 @@ PTAA    *ptaa;
     if ((ptaa = ptaaCreate(n)) == NULL)
         return (PTAA *)ERROR_PTR("ptaa not made", procName, NULL);
     for (i = 0; i < n; i++) {
-        if ((pta = ptaReadStream(fp)) == NULL)
+        if ((pta = ptaReadStream(fp)) == NULL) {
+            ptaaDestroy(&ptaa);
             return (PTAA *)ERROR_PTR("error reading pta", procName, NULL);
+        }
         ptaaAddPta(ptaa, pta, L_INSERT);
     }
 
@@ -1356,6 +1394,39 @@ PTAA  *ptaa;
 }
 
 
+/*!
+ * \brief   ptaaWriteDebug()
+ *
+ * \param[in]    filename
+ * \param[in]    ptaa
+ * \param[in]    type  0 for float values; 1 for integer values
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) Debug version, intended for use in the library when writing
+ *          to files in a temp directory with names that are compiled in.
+ *          This is used instead of ptaaWrite() for all such library calls.
+ *      (2) The global variable LeptDebugOK defaults to 0, and can be set
+ *          or cleared by the function setLeptDebugOK().
+ * </pre>
+ */
+l_int32
+ptaaWriteDebug(const char  *filename,
+               PTAA        *ptaa,
+               l_int32      type)
+{
+    PROCNAME("ptaaWriteDebug");
+
+    if (LeptDebugOK) {
+        return ptaaWrite(filename, ptaa, type);
+    } else {
+        L_INFO("write to named temp file %s is disabled\n", procName, filename);
+        return 0;
+    }
+}
+
+
 /*!
  * \brief   ptaaWrite()
  *
@@ -1369,7 +1440,8 @@ ptaaWrite(const char  *filename,
           PTAA        *ptaa,
           l_int32      type)
 {
-FILE  *fp;
+l_int32  ret;
+FILE    *fp;
 
     PROCNAME("ptaaWrite");
 
@@ -1380,10 +1452,10 @@ FILE  *fp;
 
     if ((fp = fopenWriteStream(filename, "w")) == NULL)
         return ERROR_INT("stream not opened", procName, 1);
-    if (ptaaWriteStream(fp, ptaa, type))
-        return ERROR_INT("ptaa not written to stream", procName, 1);
+    ret = ptaaWriteStream(fp, ptaa, type);
     fclose(fp);
-
+    if (ret)
+        return ERROR_INT("ptaa not written to stream", procName, 1);
     return 0;
 }
 
