@@ -45,6 +45,10 @@
  *       Static function
  *           char      *getRootNameFromArgv0()
  *
+ *  These functions are for testing and development.  They are not intended
+ *  for use with programs that run in a production environment, such as a
+ *  cloud service with unrestricted access.
+ *
  *  See regutils.h for how to use this.  Here is a minimal setup:
  *
  *  main(int argc, char **argv) {
@@ -131,6 +135,8 @@ L_REGPARAMS  *rp;
     if ((testname = getRootNameFromArgv0(argv[0])) == NULL)
         return ERROR_INT("invalid root", procName, 1);
 
+    setLeptDebugOK(1);  /* required for testing */
+
     if ((rp = (L_REGPARAMS *)LEPT_CALLOC(1, sizeof(L_REGPARAMS))) == NULL) {
         LEPT_FREE(testname);
         return ERROR_INT("rp not made", procName, 1);
@@ -170,10 +176,12 @@ L_REGPARAMS  *rp;
 
         /* Print out test name and both the leptonica and
          * image libarary versions */
-    fprintf(stderr, "\n################   %s_reg   ###############\n",
+    fprintf(stderr, "\n////////////////////////////////////////////////\n"
+                    "////////////////   %s_reg   ///////////////\n"
+                    "////////////////////////////////////////////////\n",
             rp->testname);
     vers = getLeptonicaVersion();
-    fprintf(stderr, "%s\n", vers);
+    fprintf(stderr, "%s : ", vers);
     LEPT_FREE(vers);
     vers = getImagelibVersions();
     fprintf(stderr, "%s\n", vers);
@@ -211,7 +219,6 @@ size_t   nbytes;
         return ERROR_INT("rp not defined", procName, 1);
 
     fprintf(stderr, "Time: %7.3f sec\n", stopTimerNested(rp->tstart));
-    fprintf(stderr, "################################################\n");
 
         /* If generating golden files or running in display mode, release rp */
     if (!rp->fp) {
