@@ -101,7 +101,9 @@
  *      Comments on usage:
  *
  *          The user is responsible for correctly disposing of strings
- *          that have been extracted from sarrays:
+ *          that have been extracted from sarrays.  In the following,
+ *          "str_not_owned" means the returned handle does not own the string,
+ *          and "str_owned" means the returned handle owns the string.
  *            - To extract a string from an Sarray in order to inspect it
  *              or to make a copy of it later, get a handle to it:
  *                  copyflag = L_NOCOPY.
@@ -122,6 +124,8 @@
  *                     second string array:
  *                       str-not-owned = sarrayGetString(sa, index, L_NOCOPY);
  *                       sarrayAddString(sa, str-not-owned, L_COPY).
+ *              sarrayAddString() transfers ownership to the Sarray, so never
+ *              use L_INSERT if the string is owned by another array.
  *
  *              In all cases, when you use copyflag = L_COPY to extract
  *              a string from an array, you must either free it
@@ -133,6 +137,8 @@
 #ifndef _WIN32
 #include <dirent.h>     /* unix only */
 #include <sys/stat.h>
+#include <limits.h>  /* needed for realpath() */
+#include <stdlib.h>  /* needed for realpath() */
 #endif  /* ! _WIN32 */
 #include "allheaders.h"
 
@@ -427,12 +433,13 @@ sarrayClone(SARRAY  *sa)
  *
  * \param[in]    sa string array
  * \param[in]    string  string to be added
- * \param[in]    copyflag  L_INSERT or L_COPY
+ * \param[in]    copyflag  L_INSERT, L_NOCOPY or L_COPY
  * \return  0 if OK, 1 on error
  *
  * <pre>
  * Notes:
- *      (1) See usage comments at the top of this file.
+ *      (1) See usage comments at the top of this file.  L_INSERT is
+ *          equivalent to L_NOCOPY.
  * </pre>
  */
 l_int32
@@ -448,17 +455,17 @@ l_int32  n;
         return ERROR_INT("sa not defined", procName, 1);
     if (!string)
         return ERROR_INT("string not defined", procName, 1);
-    if (copyflag != L_INSERT && copyflag != L_COPY)
+    if (copyflag != L_INSERT && copyflag != L_NOCOPY && copyflag != L_COPY)
         return ERROR_INT("invalid copyflag", procName, 1);
 
     n = sarrayGetCount(sa);
     if (n >= sa->nalloc)
         sarrayExtendArray(sa);
 
-    if (copyflag == L_INSERT)
-        sa->array[n] = string;
-    else  /* L_COPY */
+    if (copyflag == L_COPY)
         sa->array[n] = stringNew(string);
+    else  /* L_INSERT or L_NOCOPY */
+        sa->array[n] = string;
     sa->n++;
 
     return 0;
@@ -1850,12 +1857,13 @@ SARRAY  *saout;
 SARRAY *
 getFilenamesInDirectory(const char  *dirname)
 {
-char           *realdir, *name;
-l_int32         len;
+char            dir[PATH_MAX + 1];
+char           *realdir, *stat_path, *ignore;
+size_t          size;
 SARRAY         *safiles;
 DIR            *pdir;
 struct dirent  *pdirentry;
-int             dfd;
+int             dfd, stat_ret;
 struct stat     st;
 
     PROCNAME("getFilenamesInDirectory");
@@ -1863,30 +1871,39 @@ struct stat     st;
     if (!dirname)
         return (SARRAY *)ERROR_PTR("dirname not defined", procName, NULL);
 
-    realdir = genPathname(dirname, NULL);
-    pdir = opendir(realdir);
-    LEPT_FREE(realdir);
-    if (!pdir)
+        /* It's nice to ignore directories.  fstatat() works with relative
+           directory paths, but stat() requires using the absolute path.
+           Also, do not pass NULL as the second parameter to realpath();
+           use a buffer of sufficient size. */
+    ignore = realpath(dirname, dir);  /* see note above */
+    realdir = genPathname(dir, NULL);
+    if ((pdir = opendir(realdir)) == NULL) {
+        LEPT_FREE(realdir);
         return (SARRAY *)ERROR_PTR("pdir not opened", procName, NULL);
+    }
     safiles = sarrayCreate(0);
     dfd = dirfd(pdir);
     while ((pdirentry = readdir(pdir))) {
-
-        /* It's nice to ignore directories.  */
-      if ((0 == fstatat(dfd, pdirentry->d_name, &st, 0))
-          && S_ISDIR(st.st_mode)) {
+#if HAVE_FSTATAT
+        stat_ret = fstatat(dfd, pdirentry->d_name, &st, 0);
+#else
+        size = strlen(realdir) + strlen(pdirentry->d_name) + 2;
+        if (size > PATH_MAX) {
+            L_ERROR("size = %lu too large; skipping\n", procName,
+                    (unsigned long)size);
             continue;
-      }
-
-            /* Filter out "." and ".." if they're passed through */
-        name = pdirentry->d_name;
-        len = strlen(name);
-        if (len == 1 && name[len - 1] == '.') continue;
-        if (len == 2 && name[len - 1] == '.' && name[len - 2] == '.') continue;
-        sarrayAddString(safiles, name, L_COPY);
+        }
+        stat_path = (char *)LEPT_CALLOC(size, 1);
+        snprintf(stat_path, size, "%s/%s", realdir, pdirentry->d_name);
+        stat_ret = stat(stat_path, &st);
+        LEPT_FREE(stat_path);
+#endif
+        if (stat_ret == 0 && S_ISDIR(st.st_mode))
+            continue;
+        sarrayAddString(safiles, pdirentry->d_name, L_COPY);
     }
     closedir(pdir);
-
+    LEPT_FREE(realdir);
     return safiles;
 }
 
