@@ -508,11 +508,11 @@ SEL       *sel;
         lept_mkdir("lept/sel");
         pixaGetPixDimensions(pixa, 0, &w, NULL, NULL);
         pixt = pixaDisplayTiledAndScaled(pixa, 32, w, 1, 0, 10, 2);
-        pixWrite("/tmp/lept/sel/xsel1.png", pixt, IFF_PNG);
+        pixWriteDebug("/tmp/lept/sel/xsel1.png", pixt, IFF_PNG);
         pixDisplay(pixt, 0, 100);
         pixDestroy(&pixt);
         pixt = selaDisplayInPix(sela, 15, 2, 20, 1);
-        pixWrite("/tmp/lept/sel/xsel2.png", pixt, IFF_PNG);
+        pixWriteDebug("/tmp/lept/sel/xsel2.png", pixt, IFF_PNG);
         pixDisplay(pixt, 500, 100);
         pixDestroy(&pixt);
         selaWriteStream(stderr, sela);
@@ -640,11 +640,11 @@ SEL       *sel;
         lept_mkdir("lept/sel");
         pixaGetPixDimensions(pixa, 0, &w, NULL, NULL);
         pixt = pixaDisplayTiledAndScaled(pixa, 32, w, 4, 0, 10, 2);
-        pixWrite("/tmp/lept/sel/tsel1.png", pixt, IFF_PNG);
+        pixWriteDebug("/tmp/lept/sel/tsel1.png", pixt, IFF_PNG);
         pixDisplay(pixt, 0, 100);
         pixDestroy(&pixt);
         pixt = selaDisplayInPix(sela, 15, 2, 20, 4);
-        pixWrite("/tmp/lept/sel/tsel2.png", pixt, IFF_PNG);
+        pixWriteDebug("/tmp/lept/sel/tsel2.png", pixt, IFF_PNG);
         pixDisplay(pixt, 500, 100);
         pixDestroy(&pixt);
         selaWriteStream(stderr, sela);
