@@ -63,10 +63,10 @@
  *       Prime finders
  *           l_int32    findNextLargerPrime()
  *           l_int32    lept_isPrime()
-  *
+ *
  *       Gray code conversion
- *           l_uint32   convertBinaryToGrayCode()
- *           l_uint32   convertGrayToBinaryCode()
+ *           l_uint32   convertIntToGrayCode()
+ *           l_uint32   convertGrayCodeToInt()
  *
  *       Leptonica version number
  *           char      *getLeptonicaVersion()
@@ -93,7 +93,6 @@
 #include <windows.h>
 #endif  /* _WIN32 */
 
-//#include <string.h>
 #include <time.h>
 #include "allheaders.h"
 #include <math.h>
@@ -750,10 +749,10 @@ l_uint64  limit, ratio;
  *                         Gray code conversion                        *
  *---------------------------------------------------------------------*/
 /*!
- * \brief   convertBinaryToGrayCode()
+ * \brief   convertIntToGrayCode()
  *
- * \param[in]    val
- * \return  gray code value
+ * \param[in]  val    integer value
+ * \return     corresponding gray code value
  *
  * <pre>
  * Notes:
@@ -762,20 +761,20 @@ l_uint64  limit, ratio;
  * </pre>
  */
 l_uint32
-convertBinaryToGrayCode(l_uint32 val)
+convertIntToGrayCode(l_uint32 val)
 {
     return (val >> 1) ^ val;
 }
 
 
 /*!
- * \brief   convertGrayCodeToBinary()
+ * \brief   convertGrayCodeToInt()
  *
- * \param[in]    val gray code value
- * \return  binary value
+ * \param[in]  val    gray code value
+ * \return     corresponding integer value
  */
 l_uint32
-convertGrayCodeToBinary(l_uint32 val)
+convertGrayCodeToInt(l_uint32 val)
 {
 l_uint32  shift;
 
